****************
glowing_waffles
****************

This is the documentation for the affiliated package.

Reference/API
=============

.. automodapi:: glowing_waffles
.. automodapi:: glowing_waffles.differential_photometry
.. automodapi:: glowing_waffles.visualization
.. automodapi:: glowing_waffles.io
